<?php

declare(strict_types=1);

namespace App\Controller\Admin\Tools;

use App\Controller\Admin\BaseController;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Attribute\Route;

#[Route('/admin/tools', name: 'admin_tool_')]
class TrafficCounterController extends BaseController
{

    /**
     * @param Request $request
     * @return Response
     */
    #[Route(path: '/traffic-counter', name: 'traffic_counter_index')]
    public function trafficCounterAction(Request $request): Response {

        return $this->render('tool/trafficCounter/index.html.twig', [

        ]);

    }

}
